@@ -97,16 +97,34 @@ class Response:
     error = Error.UNDEFINED
     error_text = ""
     error_description = ""
+    content_type = None
 
     response = None
+    content = None
+    filename = None
 
-    def __init__(self, status_code, text=None):
-        if text:
-            try:
-                self.response = json.loads(text)
-            except json.decoder.JSONDecodeError as err:
-                self.error_text = str(err)
-                self.response = text
+    def __init__(
+            self, status_code, text=None,
+            content=None, content_type='application/json',
+            content_disposition=None):
+        self.content_type = content_type
+        self.content_disposition = content_disposition
+        if self.content_type == 'application/json':
+            if text:
+                try:
+                    self.response = json.loads(text)
+                    self.content = bytes(text, 'utf-8')
+                except json.decoder.JSONDecodeError as err:
+                    self.error_text = str(err)
+                    self.response = text
+        elif content:
+            self.content = content
+        if self.content_disposition:
+            match = re.match(
+                    'attachment; filename="(.*)"',
+                    self.content_disposition)
+            if match:
+                self.filename = match.group(1)
         errors = {
             0: (Error.DNS_ERROR, ("Name or service not known.", None)),
             400: (Error.HTTP_BAD_REQUEST, self.__error_from_server),
@@ -124,7 +142,9 @@ class Response:
             result = errors.get(status_code)
         else:
             result = (Error.UNKNOWN_ERROR,
-                      (f"An unknown error occured. {status_code}", None))
+                      (
+                          f"An unknown error occured. {status_code}",
+                          None))
 
         self.error = result[0]
         if isinstance(result[1], tuple):
@@ -296,14 +316,22 @@ class Api(ABC):
                     request.url, headers=request.headers,
                     params=request.api_params, data=request.data,
                     allow_redirects=True)
-            response = Response(result.status_code, result.text)
+            content_type = None
+            content_disposition = None
+            if 'Content-Type' in result.headers:
+                content_type = result.headers['Content-Type']
+            if 'Content-Disposition' in result.headers:
+                content_disposition = result.headers['Content-Disposition']
+            response = Response(
+                    result.status_code, result.text,
+                    result.content, content_type, content_disposition)
         except (
                 requests.exceptions.ConnectionError,
                 requests.exceptions.MissingSchema) as error:
             self.log.exception('request exception')
-            raise RequestException(
-                    'Connection error', error)
+            raise RequestException('Connection error', error)
 
+        self.log.debug('response headers: %s', result.headers)
         self.log.debug('response result: %s', response.__dict__)
 
         if response.has_error():
