@@ -2,6 +2,7 @@
 
 import os
 import sys
+import textwrap
 
 import tabulate
 
@@ -22,20 +23,24 @@ class ListParams(Params, TagsParam):
     oldest = False
     trim = False
     tags = None
+    untagged = False
 
-    def __init__(self, quantity=None, filter_read=None,
-                 filter_starred=None, oldest=None, trim=None, tags=None):
+    def __init__(self, quantity=None, filter_read=None, filter_starred=None,
+                 oldest=None, trim=None, tags=None, untagged=False):
         self.quantity = quantity
         self.filter_read = filter_read
         self.filter_starred = filter_starred
         self.oldest = oldest
         self.trim = trim
         self.tags = tags
+        self.untagged = untagged
 
     def validate(self):
         result, msg = self._validate_tags()
         if not result:
             return False, msg
+        if self.untagged and self.tags:
+            return False, 'Please set one of `untagged` or `tags` parameter.'
         return True, None
 
 
@@ -56,29 +61,34 @@ class ListCommand(Command):
         })
         entries = Entry.create_list(
                 api.request().response['_embedded']["items"])
+        if self.params.untagged:
+            entries = list(filter(lambda e: not e.tags, entries))
         return True, self.__print_entries(entries)
 
     def __print_entries(self, entries):
         entry_id_width = self.__entry_id_width(entries)
-        maxwidth = self.__get_maxwidth() - entry_id_width - 4
+        maxwidth = self.__get_maxwidth() - entry_id_width - 5
         output = []
         for item in entries:
+            _maxwidth = maxwidth
             entry_id = str(item.entry_id).rjust(entry_id_width)
 
-            title = item.title
             status = self.__read_star_char(item)
             annotation_mark = self.__annotation_mark(item)
             tags_mark = self.__tags_mark(item)
+            _maxwidth -= (2 if annotation_mark else 0)
+            _maxwidth -= (2 if tags_mark else 0)
+            title = textwrap.shorten(item.title, _maxwidth, placeholder='...')
             entry = [
                     entry_id, status,
-                    f"{title}{annotation_mark}{tags_mark}"[0:maxwidth]]
+                    f"{title}{annotation_mark}{tags_mark}"]
             output.append(entry)
         return tabulate.tabulate(output)
 
     def __get_quantity(self):
         if self.params.quantity is None:
             try:
-                return os.get_terminal_size().lines - 2
+                return os.get_terminal_size().lines - 3
             except OSError:
                 return sys.maxsize
         else:
@@ -116,6 +126,7 @@ class ListCommand(Command):
 class CountCommand(Command):
 
     def __init__(self, config, params=None):
+        Command.__init__(self)
         self.config = config
         self.params = params or ListParams()
 
@@ -123,8 +134,11 @@ class CountCommand(Command):
         api = GetListEntries(self.config, {
             ListEntriesParams.COUNT: sys.maxsize,
             ListEntriesParams.FILTER_READ: self.params.filter_read,
-            ListEntriesParams.FILTER_STARRED: self.params.filter_starred
+            ListEntriesParams.FILTER_STARRED: self.params.filter_starred,
+            ListEntriesParams.TAGS: self.params.tags
         })
-        response = api.request().response
-
-        return True, len(response["_embedded"]["items"])
+        entries = Entry.create_list(
+                api.request().response['_embedded']["items"])
+        if self.params.untagged:
+            entries = list(filter(lambda e: not e.tags, entries))
+        return True, len(entries)
