@@ -5,19 +5,23 @@ import logging
 import platform
 import subprocess
 import sys
+from pathlib import PurePath
 
 from colorama import Fore
 
 import click
+import click_repl
 
 from wallabag.commands.add import AddCommand, AddCommandParams
 from wallabag.commands.anno import (
         AnnoCommand, AnnoSubcommand, AnnoCommandParams)
 from wallabag.commands.delete import DeleteCommand, DeleteCommandParams
 from wallabag.commands.list import ListCommand, ListParams, CountCommand
-from wallabag.commands.show import ShowCommand, ShowCommandParams
+from wallabag.commands.show import ShowCommand, ShowCommandParams, Alignment
 from wallabag.commands.tags import (
         TagsCommand, TagsCommandParams, TagsSubcommand)
+from wallabag.commands.export import (
+        FormatType, ExportCommandParams, ExportCommand)
 from wallabag.commands.open import OpenCommand, OpenCommandParams
 from wallabag.commands.info import InfoCommand, InfoCommandParams
 from wallabag.commands.update import UpdateCommand, UpdateCommandParams
@@ -100,16 +104,18 @@ Would you like to create it now? [Y/n]
               help="Show read as well as unread entries.")
 @click.option('-o', '--oldest', default=False, is_flag=True,
               help="Show oldest matches instead of the newest.")
-@click.option('-t', '--trim-output', default=False, is_flag=True,
+@click.option('--trim-output/--no-trim-output', default=True, is_flag=True,
               help="Trim the titles to fit the length of the cli.")
 @click.option('-c', '--count', default=False, is_flag=True,
               help="Show a sum of matching entries.")
 @click.option('-g', '--tags', help="Return entries that matches ALL tags.")
+@click.option('--untagged', is_flag=True, help="Return entries that have no tags.")
 @click.option('-q', '--quantity', type=click.INT,
               help="Set the number of entries to show.")
 @need_config
 @click.pass_context
-def list(ctx, starred, read, all, oldest, trim_output, count, tags, quantity):
+def list(ctx, starred, read, all, oldest, trim_output,
+         count, tags, untagged, quantity):
     """
     List the entries on the wallabag account.
 
@@ -120,7 +126,8 @@ def list(ctx, starred, read, all, oldest, trim_output, count, tags, quantity):
         read = None
         starred = None
 
-    params = ListParams(quantity, read, starred, oldest, trim_output, tags)
+    params = ListParams(
+            quantity, read, starred, oldest, trim_output, tags, untagged)
     run_command(
             CountCommand(config, params) if count else
             ListCommand(config, params))
@@ -132,20 +139,27 @@ def list(ctx, starred, read, all, oldest, trim_output, count, tags, quantity):
               help="Show image links in optimized output")
 @click.option('-r', '--raw', default=False, is_flag=True,
               help="Disable wordwise trimming")
+@click.option('-w', '--width', default='80%',
+              help="Output width in percent or absolute columns count")
+@click.option('-a', '--alignment', default=Alignment.CENTER.name,
+              type=click.Choice(Alignment.list(), case_sensitive=False),
+              help="Output width in percent or absolute columns count")
 @click.option('-t', '--html', default=False, is_flag=True,
               help="Show the entry as html instead of optimized output for \
 the cli.")
 @click.argument('entry_id', required=True)
 @need_config
 @click.pass_context
-def show(ctx, entry_id, color, html, raw, image_links):
+def show(ctx, entry_id, color, html, raw, width, alignment, image_links):
     """
     Show the text of an entry.
 
     The ENTRY_ID can be found with `list` command.
     """
-    run_command(ShowCommand(
-        ctx.obj, ShowCommandParams(entry_id, color, html, raw, image_links)))
+    params = ShowCommandParams(entry_id, color, html, raw, image_links)
+    params.width = width
+    params.align = Alignment.get(alignment)
+    run_command(ShowCommand(ctx.obj, params))
 
 
 @cli.command()
@@ -395,6 +409,31 @@ def open(ctx, entry_id, open_original, browser):
                 ctx.obj, OpenCommandParams(entry_id, open_original, browser)))
 
 
+@cli.command(short_help="Export entry to file.")
+@click.option('-o', '--output', help="Output directory or file name")
+@click.option('-f', '--format', default=FormatType.JSON.name,
+              type=click.Choice(FormatType.list(), case_sensitive=False),
+              help="Export format")
+@click.option('--filename-with-id/--filename-no-id', default=True,
+              is_flag=True, help="Add id to filename")
+@click.argument('entry_id', required=True)
+@need_config
+@click.pass_context
+def export(ctx, entry_id, format, output, filename_with_id):
+    """
+    Export entry to file.
+
+    Default output to current directory.
+    """
+    output = PurePath(output) if output else None
+    format = FormatType.get(format)
+    params = ExportCommandParams(entry_id, format, output)
+    params.filename_with_id = filename_with_id
+    run_command(
+            ExportCommand(
+                ctx.obj, params))
+
+
 @cli.command(short_help="Start configuration.")
 @click.option('-c', '--check', is_flag=True,
               help="Check the config for errors.")
@@ -439,3 +478,6 @@ def run_command(command, quiet=False):
         click.echo(output)
     if not result:
         sys.exit(1)
+
+
+click_repl.register_repl(cli)
